polyfemos.front.forms — polyfemos 0.3.29 documentation

# polyfemos.front.forms

Web forms

Forms use `FlaskForm` as a base form

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Classes

`AlertHeatForm`([formdata]) | A web form for `alertheat()`.
`DatacoverageForm`([formdata]) | A web form for `datacoveragebrowser()`.
`DateForm`([formdata]) | A web form for submitting start and end dates.
`FileFormatForm`([formdata]) | Web form for selecting input fileformat
`HeaderdateForm`([formdata]) | A web form for submitting a single date
`PlotbrowserForm`([formdata]) | A web form for `plotbrowser()`.
`RIRVForm`([formdata]) | A web form for ‘Remove irrational values’ check box
`SelectNetworkForm`([formdata]) | A web form to select network
`SingleDateForm`([formdata]) | A web form for submitting a single date.
`SohTableForm`([formdata]) | A web form for `sohtable()`.
`StationsForm`([formdata]) | A web form for submitting a station selection as a string
`SubmitForm`([formdata]) | A web form for submit button.
`SummaryForm`([formdata]) | A web form for `summary()`.